/****************************************************
Generic parameter reconstructor.
This file contains the reconstructing algorithms.

This is the program for the paper:
"Rigorous parameter-reconstruction for differential
equations with noisy data."

Authors: Tomas Johnson    Uppsala University 
         Warwick Tucker   University of Bergen


***************************************************/


#ifndef PARAMRECONSTRUCT_H
#define PARAMRECONSTRUCT_H

#include <ostream> 
#include <fstream>
#include "vnode.h"
#include "list.h"
#include "Constants.h"

using namespace std;
using namespace vnodelp;


// ------- Globally accessable function -----------------------------------------------------------------
void paramReconstruct(Tfunction ODE, TFfunction ODE2,
		      const double &tol, const double &tol2, const int &n, const int &k, const int &l, 
		      const pVector &weights, iVector checkParam, iVector &time, List<iMatrix> yList);
// ------------------------------------------------------------------------------------------------------

#endif // PARAMRECONSTRUCT_H

//Input variables:

/*ODE       = name of vector field
  ODE2      = name of vector field 
  tol       = stop tolerance 
  tol2      = pre-split tolerance, use this to increase speed
  n         = number of dimensions
  k         = number of time steps
  l         = number of parameters
  weights   = using wieghted 1-norm in parameter space
  checkParm = parameter region to be searched
  time      = times when the data in yList is collected
  yList     = list of k*n matrices, consisting of data series
*/

