/****************************************************
Generic parameter reconstructor.
This file contains auxiliary functions.

This is the program for the paper:
"Rigorous parameter-reconstruction for differential
equations with noisy data."

Authors: Tomas Johnson    Uppsala University 
         Warwick Tucker   University of Bergen


****************************************************/
#include <time.h>
#include "utilities.h"
#include <iostream>

////////////////////////////////////////////////////////////////////////////
//
// 'START_TIMING' starts the clock, 'STOP_TIMING' stops the clock,
// and prints the elapsed time in hh:mm:ss. 'SHOW_TIMING' prints the
// elapsed time.
//
void clock(const command &cmd)
{
  struct tm     *ptr;          // Used for timing the program
  static time_t  time_start;   // start time
  
  if ( cmd == START_TIMING ) {
    time_start = time(NULL);
    ptr = localtime(&time_start);
    cout << "Started computations: " << asctime(ptr);
  }
  else if ( cmd == SHOW_TIMING || cmd == STOP_TIMING ) {
    int weeks   = 0;
    int days    = 0;
    int hours   = 0;
    int minutes = 0;
    double seconds;
    time_t time_stop;
    
    time_stop = time(NULL);
    ptr = localtime(&time_stop);
    if ( cmd == STOP_TIMING )
      cout << "Completed computations: " << asctime(ptr);
    seconds = difftime(time_stop, time_start);
    cout << "Elapsed run time: ";
    // Convert seconds to vv:dd:hh:mm:ss
    while ( seconds >= 60 ) { seconds -= 60; minutes++; }
    while ( minutes >= 60 ) { minutes -= 60;   hours++; }
    while (   hours >= 24 ) {   hours -= 24;    days++; }
    while (    days >=  7 ) {    days -=  7;   weeks++; }
    if ( weeks > 0)
      cout << weeks << " week" << (weeks != 1 ? "s, " : ", ");
    if ( days > 0)
      cout << days << " day" << (days != 1 ? "s, " : ", ");
    if ( hours > 0)
      cout << hours << " hour" << (hours != 1 ? "s, " : ", ");
    if ( minutes > 0)
      cout << minutes << " minute" << (minutes != 1 ? "s, " : ", ");
    cout << seconds << " second" << (seconds != 1 ? "s." : ".") << endl;
  }
}
















